@@ -2,18 +2,12 @@ import os
 import shutil
 import logging
 from modeldeploy_proxy_controller.rpc.log import create_adapter
+from modeldeploy_proxy_controller.rpc.proxy import TRANSFORMER_UPLOAD_URL, REQUIREMENTS_UPLOAD_URL
 from modeldeploy_proxy_controller.processors.nbprocessor import NotebookProcessor, REQUIREMENTS_TAG, PREPROCESSORS_TAG, POSTPROCESSORS_TAG, FUNCTIONS_TAG
 from modeldeploy_proxy_controller.rpc.errors import RPCInternalError
 import requests
 
-logger = create_adapter(logging.getLogger(__name__))
 NEW_LINES = '\n\n';
-API_HOST_URL = os.environ.get("API_HOST_URL", "http://10.78.153.14:30090")
-#API_HOST_URL = os.environ.get("API_HOST_URL", "http://modeldeploy-proxy-server-service.ever")
-API_VERSION = os.environ.get("API_VERSION", "v1")
-HOST_API_URL = "{}/api/{}/".format(API_HOST_URL, API_VERSION)
-TRANSFORMER_UPLOAD_URL = "{}/transformer/upload".format(HOST_API_URL)
-REQUIREMENTS_UPLOAD_URL = "{}/requirements/upload".format(HOST_API_URL)
 
 def parse_notebook(request, source_notebook_path):
     request.log.debug("parse_notebook {}".format(source_notebook_path))
@@ -45,6 +39,7 @@ def parse_notebook(request, source_notebook_path):
                 source = '{}'.format(function)
     transformer_path = processor.write_transformer_python(source);
     files = {'file': open(transformer_path, 'rb')}
+    request.log.debug("POST {} with files...".format(TRANSFORMER_UPLOAD_URL))
     response = requests.post(TRANSFORMER_UPLOAD_URL, files=files)
     request.log.debug(response.json())
 
@@ -58,6 +53,7 @@ def parse_notebook(request, source_notebook_path):
             requirements = '{}'.format(blocks[REQUIREMENTS_TAG][0])
     requirements_path = processor.write_requirements_file(requirements);
     files = {'file': open(requirements_path, 'rb')}
+    request.log.debug("POST {} with files...".format(REQUIREMENTS_UPLOAD_URL))
     response = requests.post(REQUIREMENTS_UPLOAD_URL, files=files)
     request.log.debug(response.json())
 
