@@ -10,6 +10,12 @@ STATUS_URL = "{}/proxy/health/status".format(PROXY_API_PREFIX)
 
 def probe(request):
     request.log.debug("probe_proxy")
+    global API_HOST_URL
+    global API_VERSION
+    global PROXY_API_PREFIX
+    global TRANSFORMER_UPLOAD_URL
+    global REQUIREMENTS_UPLOAD_URL
+    global STATUS_URL
     if not API_HOST_URL:
         try:
             cwd = os.getcwd()
